# mlopx

Status: **In Development**

Python package that allows the development of intuitive ML pipelines that are internally converted into Kubeflow pipelines.

This package focuses on optimising the deployment of ML pipelines in heterogeneous Kubernetes clusters.

This package is intended to be used in conjunction with an mlopx server instance.